@@ -6,12 +6,12 @@
 #include "surface.h"
 #include "output.h"
 #include "region.h"
+#include "surface_p.h"
 #include "wayland_pointer_p.h"
 
 #include <QGuiApplication>
 #include <QRegion>
 #include <QVector>
-#include <qpa/qplatformnativeinterface.h>
 // Wayland
 #include <wayland-client-protocol.h>
 
@@ -19,33 +19,6 @@ namespace KWayland
 {
 namespace Client
 {
-class Q_DECL_HIDDEN Surface::Private
-{
-public:
-    Private(Surface *q);
-    void setupFrameCallback();
-
-    WaylandPointer<wl_surface, wl_surface_destroy> surface;
-    bool frameCallbackInstalled = false;
-    QSize size;
-    bool foreign = false;
-    qint32 scale = 1;
-    QVector<Output *> outputs;
-
-    void setup(wl_surface *s);
-
-    static QList<Surface *> s_surfaces;
-
-private:
-    void handleFrameCallback();
-    static void frameCallback(void *data, wl_callback *callback, uint32_t time);
-    static void enterCallback(void *data, wl_surface *wl_surface, wl_output *output);
-    static void leaveCallback(void *data, wl_surface *wl_surface, wl_output *output);
-
-    Surface *q;
-    static const wl_callback_listener s_listener;
-    static const wl_surface_listener s_surfaceListener;
-};
 
 QList<Surface *> Surface::Private::s_surfaces = QList<Surface *>();
 
@@ -67,44 +40,6 @@ Surface::~Surface()
     release();
 }
 
-Surface *Surface::fromWindow(QWindow *window)
-{
-    if (!window) {
-        return nullptr;
-    }
-    QPlatformNativeInterface *native = qApp->platformNativeInterface();
-    if (!native) {
-        return nullptr;
-    }
-    window->create();
-    wl_surface *s = reinterpret_cast<wl_surface *>(native->nativeResourceForWindow(QByteArrayLiteral("surface"), window));
-    if (!s) {
-        return nullptr;
-    }
-    if (auto surface = get(s)) {
-        return surface;
-    }
-    Surface *surface = new Surface(window);
-    surface->d->surface.setup(s, true);
-    return surface;
-}
-
-Surface *Surface::fromQtWinId(WId wid)
-{
-    QWindow *window = nullptr;
-
-    for (auto win : qApp->allWindows()) {
-        if (win->winId() == wid) {
-            window = win;
-            break;
-        }
-    }
-
-    if (!window) {
-        return nullptr;
-    }
-    return fromWindow(window);
-}
 
 void Surface::release()
 {
@@ -151,6 +86,13 @@ const struct wl_callback_listener Surface::Private::s_listener = {frameCallback}
 const struct wl_surface_listener Surface::Private::s_surfaceListener = {enterCallback, leaveCallback};
 #endif
 
+void Surface::Private::removeOutput(Output *o)
+{
+    if (o && outputs.removeOne(o)) {
+        Q_EMIT q->outputLeft(o);
+    }
+}
+
 void Surface::Private::enterCallback(void *data, wl_surface *surface, wl_output *output)
 {
     Q_UNUSED(surface);
@@ -161,11 +103,7 @@ void Surface::Private::enterCallback(void *data, wl_surface *surface, wl_output
     }
     s->outputs << o;
     QObject::connect(o, &Output::removed, s->q, [s, o]() {
-        if (!s->outputs.contains(o)) {
-            return;
-        }
-        s->outputs.removeOne(o);
-        s->q->outputLeft(o);
+        s->removeOutput(o);
     });
     Q_EMIT s->q->outputEntered(o);
 }
@@ -174,12 +112,7 @@ void Surface::Private::leaveCallback(void *data, wl_surface *surface, wl_output
 {
     Q_UNUSED(surface);
     auto s = reinterpret_cast<Surface::Private *>(data);
-    Output *o = Output::get(output);
-    if (!o) {
-        return;
-    }
-    s->outputs.removeOne(o);
-    Q_EMIT s->q->outputLeft(o);
+    s->removeOutput(Output::get(output));
 }
 
 void Surface::Private::setupFrameCallback()
